""" Helper functions for download product testing """

import json
from enum import Enum
from pathlib import Path


def get_report_file(basename: str):
    """ Get a locations file from our collection in test_data """

    for file in Path.cwd().rglob(basename.upper() + '.json'):
        return file

    return None


def get_locations_report(basename: str):
    """ Get a locations report from a file in test_data """

    report_path = get_report_file(basename)

    if report_path is not None:
        with open(report_path, 'r') as content:
            locations_report = json.loads(content.read())
            return locations_report

    raise FileNotFoundError(f'{basename.upper() + ".json"} not found')


class Deliverable(Enum):
    SDM = 'SDM'
    BDF = 'BDF'
    MS = 'MS'
    CMS = 'CMS'
    IMG = 'IMG'
    TAR = 'TAR'
    # VLBA
    IDIFITS = 'IDIFITS'

    @staticmethod
    def from_str(key: str):
        for dtype in Deliverable:
            if dtype.value == key:
                return dtype
        return None


class DeliverableProduct:

    def __init__(self, dtype: Deliverable, file_info: dict):
        self.type = dtype
        self.file_info = file_info
